/* Loading of PEM encoded files with optional encryption
 * Copyright (C) 2001-2003 Andreas Steffen, Zuercher Hochschule Winterthur
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  See <http://www.fsf.org/copyleft/gpl.txt>.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * RCSID $Id: pem.h,v 1.1 2003/09/12 19:24:42 ken Exp $
 */

extern err_t pemtobin(chunk_t *blob, prompt_pass_t *pass, const char* label
    , bool *pgp);
